Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5994)

Unified Diff: chrome/browser/extensions/api/proxy/proxy_api_helpers.h

Issue 12315019: Change ProxyRules to handle ProxyLists rather than just single ProxyServer instances. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/proxy/proxy_api_helpers.h
diff --git a/chrome/browser/extensions/api/proxy/proxy_api_helpers.h b/chrome/browser/extensions/api/proxy/proxy_api_helpers.h
index 064b5c2565b57c9b1c23bda06251b48fdf30d678..15946c0a7ad36ad9097a785859c7c6619590be52 100644
--- a/chrome/browser/extensions/api/proxy/proxy_api_helpers.h
+++ b/chrome/browser/extensions/api/proxy/proxy_api_helpers.h
@@ -116,9 +116,9 @@ base::DictionaryValue* CreateProxyRulesDict(
const ProxyConfigDictionary& proxy_config);
// Creates and returns a ProxyServer dictionary as defined in the extension API
-// with values from a net::ProxyServer object. Never returns NULL. Ownership is
-// passed to the caller.
-base::DictionaryValue* CreateProxyServerDict(const net::ProxyServer& proxy);
+// with values from a net::ProxyList containing exactly one net::ProxyServer
+// object. Never returns NULL. Ownership is passed to the caller.
+base::DictionaryValue* CreateProxyServerDict(const net::ProxyList& proxies);
// Creates and returns a PacScript dictionary as defined in the extension API
// with the values of a ProxyconfigDictionary configured for pac scripts.

Powered by Google App Engine
This is Rietveld 408576698